@@ -6,19 +6,14 @@ from .Refund import Refund
 
 
 class DecidirSDK:
-    def __init__(self, merchant, merchant_cadena=None,site_id=None,distributed=False):
-        if distributed:
-            credentials = merchant_cadena['credentials']['decidir']
-            self.payment_type = 'distributed'
-        else:
-            credentials = merchant['credentials']['decidir']
-            self.payment_type = 'single'
+    def __init__(self, merchant):
+        credentials = merchant['credentials']['decidir']
         self.url = 'https://developers.decidir.com/api/v2'
         self.private_key = credentials['access_token']
         self.public_key = credentials['public_key']
         self.merchant_id = merchant['_id']
         self.merchant_name = merchant['name']
-        self.site_id = site_id
+        self.site_ids = credentials['site_ids'] #distributed, cobro_por_uso, checkout, cobros_recurrentes
 
     def customer(self):
         return Customer(self.url, self.private_key, self.public_key)
