@@ -81,17 +81,46 @@ class Payment:
                 'id': payment_data['payer']['decidir_id'],
                 'email': payment_data['payer']['email']
             },
-            'site_transaction_id': site_transaction_id,     # str(uuid4())
+            'site_transaction_id': site_transaction_id,
             'token': payment_data['token'],
             'payment_method_id': 1,    # Peso Argentino
             'bin': payment_data['bin'],    # primeros 6 digitos de la tarjeta
             'currency': 'ARS',
             'installments': 1,
-            'payment_type': self.payment_type,
+            'payment_type': 'single',
             'establishment_name': '-',  # opcional
             'sub_payments': []
         }
-        if self.payment_type == 'distributed':
+        # if self.payment_type == 'distributed':
+        #     application_fee = round(payment_data['application_fee'], 2) * 100
+        #     body['sub_payments'] = [
+        #         {
+        #             'site_id': payment_data['seller_site_id'],
+        #             'installments': 1,
+        #             'amount': total_amount - application_fee
+        #         }, {
+        #             'site_id': self.site_id,    # Cadena
+        #             'installments': 1,
+        #             'amount': application_fee
+        #         }
+        #     ]
+        # else:
+        #     body['amount'] = total_amount
+        #     body['site_id'] = self.site_id
+        if payment_data['payment_type'] == 'cobro_por_uso':
+            body['payment_type'] = 'single'
+            body['site_id'] = self.site_ids['cobro_por_uso']
+
+        elif payment_data['payment_type'] == 'checkout':
+            body['payment_type'] = 'single'
+            body['site_id'] = self.site_ids['checkout']
+
+        elif payment_data['payment_type'] == 'cobros_recurrentes':
+            body['payment_type'] = 'single'
+            body['site_id'] = self.site_ids['cobros_recurrentes']
+
+        elif payment_data['payment_type'] == 'distributed':
+            body['payment_type'] = 'distributed'
             application_fee = round(payment_data['application_fee'], 2) * 100
             body['sub_payments'] = [
                 {
@@ -99,15 +128,12 @@ class Payment:
                     'installments': 1,
                     'amount': total_amount - application_fee
                 }, {
-                    'site_id': self.site_id,    # Cadena
+                    'site_id': self.site_ids['distributed'],
                     'installments': 1,
                     'amount': application_fee
-                }
-            ]
-        else:
-            body['amount'] = total_amount
-            body['site_id'] = self.site_id
+                }]
 
+        # Si viene informacion adicional
         additional_information = [
             'installments',
             'establishment_name'
@@ -116,6 +142,7 @@ class Payment:
             if item in payment_data.keys():
                 body[item] = payment_data[item]
 
+        # Se genera la request
         r = requests.post(self.url + '/payments', headers=self.headers, data=json.dumps(body))
         response = r.json()
         if r.status_code < 400:
